@@ -30,7 +30,7 @@
     FALSE
 }
 
-.is_whole_or_NA <- function (x, tol = .Machine$double.eps^0.5) {
+.is_whole_or_NA <- function(x, tol = .Machine$double.eps^0.5) {
     if (is.integer(x))
         return(TRUE)
     if (is.double(x) && all(abs(x - round(x)) < tol | is.na(x)))
@@ -81,5 +81,10 @@
     if (inherits(x, "grates_period"))
         return(grates::scale_x_grates_period)
     if (inherits(x, "grates_int_period"))
-        return(grates::scale_x_grates_int_period)
+        return(grates::scale_x_grates_int_period) # nolint: return_linter.
+}
+
+# null coalescing operator
+if (getRversion() <= "4.4.0") {
+    `%||%` = function(x, y) if (is.null(x)) y else x # nolint: coalesce_linter.
 }
